==> om-6.x-2.5.tar.gz: om/om_html5_subtheme/page.tpl.php <==
<!DOCTYPE html>
<html lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
	<?php print $head; ?>
	<title><?php print $head_title; ?></title>
	<?php print $styles; ?>
	<!--[if IE  ]><?php print om_get_ie_styles('ie'); ?><![endif]-->
	<!--[if IE 6]><?php print om_get_ie_styles('ie6'); ?><![endif]-->
	<!--[if IE 7]><?php print om_get_ie_styles('ie7'); ?><![endif]-->
	<!--[if IE 8]><?php print om_get_ie_styles('ie8'); ?><![endif]-->
	<!--[if IE 9]><?php print om_get_ie_styles('ie9'); ?><![endif]-->
	<?php print $scripts; ?>
  <!--[if lt IE 9]><script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->	
</head>
<body class="<?php print $body_classes; ?>">
<div id="page" class="wrapper wrapper-level-1 wrapper-page row rows-1 row-1-1 row-1 first last wrapper-outer">
	<header class="wrapper wrapper-level-2 wrapper-header row rows-5 row-5-1 row-1 first"><div id="header-inner" class="wrapper-inner">
		<?php print theme('identity', $logo, $site_name, $site_slogan, $front_page); ?>
		<?php print $header_block_region; ?>
		<?php print theme('search_box', $search_box); ?>
	</div></header><!-- /#header-inner, /header -->
	<nav class="wrapper wrapper-level-2 wrapper-navigation row rows-5 row-5-2 row-2"><div id="navigation-inner" class="wrapper-inner">
		<?php print theme('menu', 'main-menu', $main_menu, $main_menu_tree); ?>
		<?php print theme('menu', 'secondary-menu', $secondary_menu, $secondary_menu_tree); ?>
		<?php print $menu_bar_region; ?>
	</div></nav><!-- /#navigation-inner, /nav -->
	<?php print $highlighted_region; ?>
	<section id="container" class="wrapper wrapper-level-2 wrapper-container row rows-5 row-5-4 row-4"><div id="container-inner" class="wrapper-inner">
		<?php print $sidebar_first_region; ?>
		<div id="main" class="wrapper wrapper-level-3 wrapper-main column columns-3 column-3-3 column-3 last">
			<?php print $breadcrumb; ?>
			<div id="main-inner" class="wrapper wrapper-level-4 wrapper-main-inner row rows-2 row-2-1 row-1 first">
				<?php print theme('content_elements', $mission, $tabs, $title) ?>
				<?php print $help; ?>
				<?php print $messages; ?>
				<?php print $content_region; ?>
				<?php print $feed_icons; ?>
			</div><!-- /#main-inner -->
		</div><!-- /#main -->
		<?php print $sidebar_second_region; ?>		
		<div class="clearfix"></div>
	</div></section><!-- /#container-inner, /#container -->
	<footer class="wrapper wrapper-level-2 wrapper-footer-wrapper row rows-5 row-5-5 row-5 last"><div id="footer-wrapper-inner" class="wrapper-inner">
		<?php print $footer_region; ?>
		<?php print $footer_message_region; ?>
	</div></footer><!-- /#footer-wrapper-inner, /footer -->
</div><!-- /#page -->
<?php print $closure; ?>

</body>
</html>

==> om-6.x-2.7.tar.gz: om/om_html5_subtheme/page.tpl.php <==
<!DOCTYPE html>
<html lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
	<?php print $head; ?>
	<title><?php print $head_title; ?></title>
	<?php print $styles; ?>
	<!--[if IE  ]><?php print om_get_ie_styles('ie'); ?><![endif]-->
	<!--[if IE 6]><?php print om_get_ie_styles('ie6'); ?><![endif]-->
	<!--[if IE 7]><?php print om_get_ie_styles('ie7'); ?><![endif]-->
	<!--[if IE 8]><?php print om_get_ie_styles('ie8'); ?><![endif]-->
	<!--[if IE 9]><?php print om_get_ie_styles('ie9'); ?><![endif]-->
	<?php print $scripts; ?>
  <!--[if lt IE 9]><script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->	
</head>
<body class="<?php print $body_classes; ?>">
<div class="wrapper-outer">
	<header class="wrapper wrapper-level-2 wrapper-header row rows-5 row-5-1 row-1 first"><div id="header-inner" class="wrapper-inner">
		<?php print theme('identity', $logo, $site_name, $site_slogan, $front_page); ?>
		<?php print $header_block_region; ?>
		<?php print theme('search_box', $search_box); ?>
	</div></header><!-- /#header-inner, /header -->
	<nav class="wrapper wrapper-level-2 wrapper-navigation row rows-5 row-5-2 row-2"><div id="navigation-inner" class="wrapper-inner">
		<?php print theme('menu', 'main-menu', $main_menu, $main_menu_tree); ?>
		<?php print theme('menu', 'secondary-menu', $secondary_menu, $secondary_menu_tree); ?>
		<?php print $menu_bar_region; ?>
	</div></nav><!-- /#navigation-inner, /nav -->
	<?php print $highlighted_region; ?>
	<section id="container" class="wrapper wrapper-level-2 wrapper-container row rows-5 row-5-4 row-4"><div id="container-inner" class="wrapper-inner">
		<?php print $sidebar_first_region; ?>
		<div id="main" class="wrapper wrapper-level-3 wrapper-main column columns-3 column-3-3 column-3 last">
			<?php print $breadcrumb; ?>
			<div id="main-inner" class="wrapper wrapper-level-4 wrapper-main-inner row rows-2 row-2-1 row-1 first">
				<?php print theme('content_elements', $mission, $tabs, $title) ?>
				<?php print $help; ?>
				<?php print $messages; ?>
				<?php print $content_region; ?>
				<?php print $feed_icons; ?>
			</div><!-- /#main-inner -->
		</div><!-- /#main -->
		<?php print $sidebar_second_region; ?>		
		<div class="clearfix"></div>
	</div></section><!-- /#container-inner, /#container -->
	<footer class="wrapper wrapper-level-2 wrapper-footer-wrapper row rows-5 row-5-5 row-5 last"><div id="footer-wrapper-inner" class="wrapper-inner">
		<?php print $footer_region; ?>
		<?php print $footer_message_region; ?>
	</div></footer><!-- /#footer-wrapper-inner, /footer -->
</div><!-- /#page -->
<?php print $closure; ?>

</body>
</html>
